#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#


# default value in case of no qubes-builder's one

Name:		qubes-gui-agent
Version:	4.0.29
Release:	1%{dist}
Summary:	The Qubes GUI Agent for AppVMs

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org


%define pa_ver_full %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1)
%define pa_ver_major_minor %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1 | cut -d "." -f 1,2)

BuildRequires:	gcc
BuildRequires:	libX11-devel
BuildRequires:	libXcomposite-devel
BuildRequires:	libXdamage-devel
BuildRequires:	libXt-devel
BuildRequires:	libtool-ltdl-devel
BuildRequires:	pulseaudio-libs-devel >= 0.9.21, pulseaudio-libs-devel <= 13.99.1
BuildRequires:	xorg-x11-server-devel
BuildRequires:	pam-devel
BuildRequires:	qubes-libvchan-xen-devel
BuildRequires:	qubes-gui-common-devel >= 3.2.0
BuildRequires:	qubes-db-devel
Requires:	Xorg %(xserver-sdk-abi-requires ansic)
Requires:	Xorg %(xserver-sdk-abi-requires videodrv)
Requires:	qubes-core-vm >= 3.0.14
Requires:	xorg-x11-xinit
Requires:	qubes-libvchan-xen
Requires:	python%{python3_pkgversion}-xcffib
Requires:   xorg-x11-server-Xorg
Provides:   qubes-gui-vm = %{version}-%{release}
Obsoletes:  qubes-gui-vm < 4.0.0

Source0: %{name}-%{version}.tar.gz

%package -n pulseaudio-qubes
Summary: Audio support for Qubes VM
# The vchan sink needs .h files from pulseaudio sources
# that are not exported by any *-devel packages; thus they are internal and
# possible to change across version. They are copied to gui git.
# It is possible that our code will work fine with any later pulseaudio
# version; but this needs to be verified for each pulseaudio version.
Requires:	pulseaudio = %{pa_ver_full}
Conflicts:  qubes-gui-vm < 4.0.0

%description -n pulseaudio-qubes
Pulseaudio module to enable sound support in Qubes VM

%package xfce
Summary: XFCE desktop support for Qubes VM

%description xfce
XFCE desktop support for Qubes VM

%description
The Qubes GUI agent that needs to be installed in VM in order to provide the
Qubes fancy GUI.

%prep
%setup -q

rm -f pulse/pulsecore
ln -s pulsecore-%{pa_ver_full} pulse/pulsecore

%build
%{?set_build_flags}
#make clean
make BACKEND_VMM=xen appvm

%install
rm -rf $RPM_BUILD_ROOT
make install install-xfce DESTDIR=$RPM_BUILD_ROOT \
                     LIBDIR=%{_libdir} \
                     DATADIR=%{_datadir} \
                     PA_VER_FULL=%{pa_ver_full}

%post
if [ -x /bin/systemctl ] && readlink /sbin/init | grep -q systemd; then
    /bin/systemctl enable qubes-gui-agent.service 2> /dev/null
fi

%post -n pulseaudio-qubes

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%preun
if [ "$1" = 0 ] ; then
	chkconfig qubes-gui-agent off
    [ -x /bin/systemctl ] && /bin/systemctl disable qubes-gui-agent.service
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi

%posttrans
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

if [ -d '/etc/init.d' ] && ! [ "$(ls -A /etc/init.d/ 2> /dev/null)" ]; then
    rmdir /etc/init.d
fi

%triggerin -n pulseaudio-qubes -- pulseaudio-libs

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}


%files
%defattr(-,root,root,-)
/usr/bin/qubes-gui
/usr/bin/qubes-gui-runuser
/usr/bin/qubes-session
/usr/bin/qubes-run-xorg
/usr/bin/qubes-change-keyboard-layout
/usr/bin/qubes-set-monitor-layout
%{_libdir}/xorg/modules/drivers/qubes_drv.so
%{_libdir}/xorg/modules/drivers/dummyqbs_drv.so
%attr(0644,root,root) /etc/X11/xorg-qubes.conf.template
/etc/profile.d/qubes-gui.sh
/etc/profile.d/qubes-gui.csh
/etc/profile.d/qubes-session.sh
%config /etc/pam.d/qubes-gui-agent
%config /etc/security/limits.d/90-qubes-gui.conf
%config /etc/xdg/Trolltech.conf
/etc/X11/xinit/xinitrc.d/qubes-keymap.sh
/etc/X11/xinit/xinitrc.d/20qt-x11-no-mitshm.sh
/etc/X11/xinit/xinitrc.d/20qt-gnome-desktop-session-id.sh
/etc/qubes-rpc/qubes.SetMonitorLayout
%config /etc/sysconfig/desktop
/etc/sysconfig/modules/qubes-u2mfn.modules
/lib/systemd/system/qubes-gui-agent.service
/lib/udev/rules.d/70-master-of-seat.rules
/usr/lib/modules-load.d/qubes-gui.conf
/usr/lib/tmpfiles.d/qubes-session.conf
/usr/lib/sysctl.d/30-qubes-gui-agent.conf
%{_datadir}/glib-2.0/schemas/20_qubes-gui-vm.gschema.override
/usr/lib/qubes/icon-sender
/etc/xdg/autostart/qubes-icon-sender.desktop
%dir /var/log/qubes

%files -n pulseaudio-qubes
/usr/lib/tmpfiles.d/qubes-pulseaudio.conf
/etc/pulse/qubes-default.pa
/usr/bin/start-pulseaudio-with-vchan
%{_libdir}/pulse-%{pa_ver_major_minor}/modules/module-vchan-sink.so
/etc/xdg/autostart/qubes-pulseaudio.desktop

%files xfce
/etc/X11/xinit/xinitrc.d/50-xfce-desktop.sh

%changelog
* Sat Apr 18 2020 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-agent-linux

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3a33abf
- version 4.0.29

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6493688
- travis: use imported config

* Sat Apr 18 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 9186332
- pulseaudio 13.99.1

* Sat Apr 18 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - d848bf1
- pulseaudio 13.99.1: add internal headers

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 73be82a
- version 4.0.28

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a4182f5
- pulse: fix pa_proplist_set[fs] usage

* Sat Apr 18 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 22e6859
- pulseaudio: support reconnecting

* Sat Apr 18 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 9269574
- module-vchan-sink: log for domid used

* Sat Apr 18 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f0d6adf
- module-vchan-sink: convert tabs to spaces

* Sat Apr 18 2020 xaki23 <tvguho-knxv23-tct.e23f2f1b@hashmail.org> - c052ef0
- add modargs for target domid and sink/source descr strings

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d03b6a1
- create /etc/qubes-rpc directory before placing a symlink there

* Sat Apr 18 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - db11553
- Replace non-executable qubes.SetMonitorLayout file with a symlink

* Wed Apr 01 2020 Yukikoo <github@neowutran.ovh> - ddedb60
- Archlinux: more permissive with xorg-server update

* Sun Jan 19 2020 Zaoqi <zaomir@outlook.com> - 59a3e33
- archlinux: qubes-vm-gui: update PKGBUILD

* Wed Dec 25 2019 Neowutran <me@neowutran.ovh> - 36b1f6b
- ARCHLINUX: Allow xorg-server<1.20.7

* Wed Dec 25 2019 Neowutran <me@neowutran.ovh> - 0e36534
- ARCHLINUX: xf86dgaproto doesn't exist anymore, and is no longer required. Removing it from the dependencies.

* Sun Oct 20 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - ab6d95c
- travis: switch to bionic

* Mon Oct 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4f2a157
- version 4.0.27

* Mon Oct 07 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1c0bfa6
- Escape '$p' in systemd unit file

* Thu Sep 26 2019 Neowutran <me@neowutran.ovh> - 40c028e
- Archlinux: Allow any pulseaudio version between 13.0 and 14.0 for qubes-vm-pulseaudio

* Sun Sep 22 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a8e6269
- version 4.0.26

* Sun Sep 22 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1bf34f5
- archlinux: do not force python2 anymore

* Sun Sep 22 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 29236a5
- rpm: update pulseaudio version

* Sun Sep 22 2019 Neowutran <me@neowutran.ovh> - 124d844
- add pulseaudio 13.0 headers

* Sat Sep 21 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5bf99b5
- Disable "transparent hugepage" kernel feature

* Sat Sep 21 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8059f63
- travis: add fc30, switch to xenial

* Fri Sep 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - a7ef955
- version 4.0.25

* Fri Sep 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - def87d2
- Fix qubes-change-keyboard-layout after migrating to python3

* Fri Sep 06 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 48e2d7a
- spec: handle newer pulseaudio for Fedora 31+

* Fri Sep 06 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 91de9ea
- Add pulseaudio-12.99.2 symlinked headers

* Fri Sep 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6483d27
- debian: add Build-Depends: lsb-release

* Mon Jun 17 2019 Laurent <haarlaurent67@hotmail.fr> - 1c15632
- Update PKGBUILD

* Sat Jun 01 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 877e647
- version 4.0.24

* Fri May 31 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - ffcbc91
- spec: better use rmdir and check if exist for /etc/init.d

* Fri May 31 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 566cb94
- spec: ensure we remove empty /etc/inid.d folder

* Fri May 31 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - cdcb558
- Init script qubes-gui-agent is not needed anymore

* Fri Apr 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7a3bb89
- version 4.0.23

* Fri Apr 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ad8fd1a
- Convert qubes-change-keyboard-layout to python3

* Wed Mar 20 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 18a0b9f
- version 4.0.22

* Wed Mar 20 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5478890
- video-dummy: fix off by one error in memory size check

* Fri Mar 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8b8b883
- version 4.0.21

* Fri Mar 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8c4735d
- Indentation fix

* Fri Mar 01 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 86b5b8d
- Fix GCC9 warning about size in strncpy

* Fri Jan 18 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0005614
- Drop /etc/X11/Xwrapper.config

* Fri Jan 11 2019 Olivier MEDOC <o_medoc@yahoo.fr> - d456f65
- archlinux: switch to using icon-sender with python3

* Fri Jan 04 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bc54e44
- version 4.0.20

* Sat Dec 22 2018 Frédéric Pierret (fepitre) <frederic.epitre@orange.fr> - e694db7
- spec: fix missing abi version requirement

* Tue Nov 27 2018 Olivier MEDOC <o_medoc@yahoo.fr> - 01ea25f
- fix install path to follow archlinux packaging guidelines

* Wed Nov 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9f15169
- version 4.0.19

* Fri Nov 16 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - aca4099
- vmside: cleanup calling qubes-run-xorg, terminate it on service stop

